@@ -78,7 +78,8 @@ mod test {
 			.parent()
 			.unwrap()
 			.to_path_buf()
-			.join("cliff.toml")
+			.join("config")
+			.join(crate::DEFAULT_CONFIG)
 			.to_str()
 			.unwrap()
 			.to_string();
